VERSION 1.0 CLASS
BEGIN
  MultiUse = -1  'True
  Persistable = 0  'NotPersistable
  DataBindingBehavior = 0  'vbNone
  DataSourceBehavior  = 0  'vbNone
  MTSTransactionMode  = 0  'NotAnMTSObject
END
Attribute VB_Name = "CWave"
Attribute VB_GlobalNameSpace = False
Attribute VB_Creatable = True
Attribute VB_PredeclaredId = False
Attribute VB_Exposed = False
'** Class : CWave ********************************************************************
'
' DESCRIPTION
'
'   This is a sound-wave class.
'
' -----------------------------------------------------------------
' HISTORY
' Version  Date       Author  Status
' -----------------------------------------------------------------
' 000.000  28.08.1999   XP    File creation
'
'
'*************************************************************************************

Option Explicit

' ==================== PUBLIC CONSTANTS ==============================================

' ==================== PUBLIC TYPES ==================================================

' ==================== PUBLIC VARIABLES ==============================================

' ==================== PRIVATE CONSTANTS =============================================

Private Const SND_SYNC = &H0                               ' Play synchronously (default)
Private Const SND_ASYNC = &H1                              ' Play asynchronously
Private Const SND_NODEFAULT = &H2                          ' Do not use default sound
Private Const SND_LOOP = &H8                               ' Loop the sound until next sndPlaySound
Private Const SND_NOSTOP = &H10                            ' Do not stop any currently playing sound
Private Const SND_PURGE = &H40                             ' Purge nonstatic events for task
Private Const SND_FILENAME = &H20000                       ' Name is a file name

' Definition code

Private Const bDefAsync As Boolean = True
Private Const bDefRepeat As Boolean = False
Private Const bDefYield As Boolean = False

' Error code

Private Const KErrNoError = 0
Private Const KErrUnableToPlay = 1
Private Const KErrUnableToPlayResource = 2
Private Const KErrUnableToStopPlaying = 3

' ==================== PRIVATE TYPES =================================================

' ==================== PRIVATE VARIABLES =============================================

Private m_bAsync As Boolean
Private m_bRepeat As Boolean
Private m_bYield As Boolean
Private m_sFileName As String

' ==================== PRIVATE DECLARATIONS ==========================================

Private Declare Function PlaySound Lib "winmm.dll" Alias "PlaySoundA" (ByVal _
        lpszName As String, ByVal hModule As Long, ByVal dwFlags As Long) As Long


'-- Public Property Let : Async ------------------------------------------------------
'
' DESCRIPTION
'
'   This property lets the Async flag
'
' PARAMETERS
'
'   (I)  bNewVal     : The new value for this flag
'
' AUTHORS
'
' Created            28.08.1999/XP
' Last Modification  dd.mm.1999/XP
'
'-------------------------------------------------------------------------------------

Public Property Let Async(ByVal bNewVal As Boolean)

    '-- Declarations -------------------

    '-- Code ---------------------------

    m_bAsync = bNewVal


    '-- Normal termination -------------

End Property


'-- Public Property Get : Async ------------------------------------------------------
'
' DESCRIPTION
'
'   This property gets the value of the Async flag.
'
' RETURN
'
'   See explanation below
'
' AUTHORS
'
' Created            28.08.1999/XP
' Last Modification  dd.mm.1999/XP
'
'-------------------------------------------------------------------------------------

Public Property Get Async() As Boolean

    '-- Declarations -------------------

    '-- Code ---------------------------

    Async = m_bAsync


    '-- Normal termination -------------

End Property


'-- Public Property Let : Repeat -----------------------------------------------------
'
' DESCRIPTION
'
'   This property lets the Repeat flag
'
' PARAMETERS
'
'   (I)  bNewVal     : The new value for this flag
'
' AUTHORS
'
' Created            28.08.1999/XP
' Last Modification  dd.mm.1999/XP
'
'-------------------------------------------------------------------------------------

Public Property Let Repeat(ByVal bNewVal As Boolean)

    '-- Declarations -------------------

    '-- Code ---------------------------

    m_bRepeat = bNewVal


    '-- Normal termination -------------

End Property


'-- Public Property Get : Repeat -----------------------------------------------------
'
' DESCRIPTION
'
'   This property gets the value of the Repeat flag.
'
' RETURN
'
'   See explanation below
'
' AUTHORS
'
' Created            28.08.1999/XP
' Last Modification  dd.mm.1999/XP
'
'-------------------------------------------------------------------------------------

Public Property Get Repeat() As Boolean

    '-- Declarations -------------------

    '-- Code ---------------------------

    Repeat = m_bRepeat


    '-- Normal termination -------------

End Property


'-- Public Property Let : Yield ------------------------------------------------------
'
' DESCRIPTION
'
'   This property lets the Yield flag
'
' PARAMETERS
'
'   (I)  bNewVal     : The new value for this flag
'
' AUTHORS
'
' Created            28.08.1999/XP
' Last Modification  dd.mm.1999/XP
'
'-------------------------------------------------------------------------------------

Public Property Let Yield(ByVal bNewVal As Boolean)

    '-- Declarations -------------------

    '-- Code ---------------------------

    m_bYield = bNewVal


    '-- Normal termination -------------

End Property


'-- Public Property Get : Yield ------------------------------------------------------
'
' DESCRIPTION
'
'   This property gets the value of the Yield flag.
'
' RETURN
'
'   See explanation below
'
' AUTHORS
'
' Created            28.08.1999/XP
' Last Modification  dd.mm.1999/XP
'
'-------------------------------------------------------------------------------------

Public Property Get Yield() As Boolean

    '-- Declarations -------------------

    '-- Code ---------------------------

    Yield = m_bYield


    '-- Normal termination -------------

End Property


'-- Public Property Let : FileName ---------------------------------------------------
'
' DESCRIPTION
'
'   This property lets the file name of the wave sound.
'
' PARAMETERS
'
'   (I)  sFileName   : The file name of the sound
'
' AUTHORS
'
' Created            28.08.1999/XP
' Last Modification  dd.mm.1999/XP
'
'-------------------------------------------------------------------------------------

Public Property Let FileName(ByVal sFileName As String)

    '-- Declarations -------------------

    '-- Code ---------------------------

    m_sFileName = sFileName


    '-- Normal termination -------------

End Property


'-- Public Property Get : FileName ---------------------------------------------------
'
' DESCRIPTION
'
'   This property gets the file name of the wave sound.
'
' RETURN
'
'   See explanation below
'
' AUTHORS
'
' Created            28.08.1999/XP
' Last Modification  dd.mm.1999/XP
'
'-------------------------------------------------------------------------------------

Public Property Get FileName() As String

    '-- Declarations -------------------

    '-- Code ---------------------------

    FileName = m_sFileName


    '-- Normal termination -------------

End Property


'-- Public Function : StopPlaying ----------------------------------------------------
'
' DESCRIPTION
'
'   This function stops the sound playing.
'
' RETURN
'
'   Error code
'
' AUTHORS
'
' Created            28.08.1999/XP
' Last Modification  dd.mm.1999/XP
'
'-------------------------------------------------------------------------------------

Public Function StopPlaying() As Integer

    '-- Declarations -------------------

    '-- Code ---------------------------

    If PlaySound(vbNullString, App.hInstance, SND_PURGE) Then
        StopPlaying = KErrNoError
    Else
        StopPlaying = KErrUnableToStopPlaying
    End If


    '-- Normal termination -------------

End Function


'-- Public Function : Play -----------------------------------------------------------
'
' DESCRIPTION
'
'   This function starts the sound playing.
'
' RETURN
'
'   Error code
'
' AUTHORS
'
' Created            28.08.1999/XP
' Last Modification  dd.mm.1999/XP
'
'-------------------------------------------------------------------------------------

Public Function Play() As Integer

    '-- Declarations -------------------

    Dim lFlags As Long


    '-- Code ---------------------------

    lFlags = SND_FILENAME Or SND_NODEFAULT

    If m_bAsync Then lFlags = lFlags Or SND_ASYNC
    If m_bRepeat Then lFlags = lFlags Or SND_LOOP
    If m_bYield Then lFlags = lFlags Or SND_NOSTOP

    If PlaySound(m_sFileName, &H0&, lFlags) Then
        Play = KErrNoError
    Else
        Play = KErrUnableToPlay
    End If


    '-- Normal termination -------------

End Function


'-- Private Sub : Class_Initialize ---------------------------------------------------
'
' DESCRIPTION
'
'   This procedure initializes this object.
'
' AUTHORS
'
' Created            28.08.1999/XP
' Last Modification  dd.mm.1999/XP
'
'-------------------------------------------------------------------------------------

Private Sub Class_Initialize()

    '-- Declarations -------------------

    '-- Code ---------------------------

    m_bAsync = bDefAsync
    m_bRepeat = bDefRepeat
    m_bYield = bDefYield


    '-- Normal termination -------------

End Sub
